==> haskell-clash-prelude-1.6.6-4-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-clash-prelude.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 clash-prelude
version:              1.6.6
visibility:           public
id:                   clash-prelude-1.6.6-FjFoMXWmgppEiwr6KGaISr
key:                  clash-prelude-1.6.6-FjFoMXWmgppEiwr6KGaISr
license:              BSD-2-Clause
copyright:
    Copyright © 2013-2016, University of Twente,
    2016-2017, Myrtle Software Ltd,
    2017-2019, QBayLogic B.V., Google Inc.,
    2021-2023, QBayLogic B.V.

maintainer:           QBayLogic B.V. <devops@qbaylogic.com>
author:               The Clash Authors
homepage:             https://clash-lang.org/
synopsis:
    Clash: a functional hardware description language - Prelude library

description:
    Clash is a functional hardware description language that borrows both its
    syntax and semantics from the functional programming language Haskell. The
    Clash compiler transforms these high-level descriptions to low-level
    synthesizable VHDL, Verilog, or SystemVerilog.

    Features of Clash:

    * Strongly typed, but with a very high degree of type inference, enabling both
    safe and fast prototyping using concise descriptions.

    * Interactive REPL: load your designs in an interpreter and easily test all
    your component without needing to setup a test bench.

    * Higher-order functions, with type inference, result in designs that are
    fully parametric by default.

    * Synchronous sequential circuit design based on streams of values, called
    @Signal@s, lead to natural descriptions of feedback loops.

    * Support for multiple clock domains, with type safe clock domain crossing.


    This package provides:

    * Prelude library containing datatypes and functions for circuit design

    To use the library:

    * Import "Clash.Prelude"

    * Alternatively, if you want to explicitly route clock and reset ports,
    for more straightforward multi-clock designs, you can import the
    "Clash.Explicit.Prelude" module. Note that you should not import
    "Clash.Prelude" and "Clash.Explicit.Prelude" at the same time as they
    have overlapping definitions.

    A preliminary version of a tutorial can be found in "Clash.Tutorial", for a
    general overview of the library you should however check out "Clash.Prelude".
    Some circuit examples can be found in "Clash.Examples".

category:             Hardware
abi:                  2fca665de0088bce6cb1e47a26ec875f
exposed:              True
exposed-modules:
    Clash.Annotations.BitRepresentation
    Clash.Annotations.BitRepresentation.Deriving
    Clash.Annotations.BitRepresentation.Internal
    Clash.Annotations.BitRepresentation.Util
    Clash.Annotations.Primitive Clash.Annotations.SynthesisAttributes
    Clash.Annotations.TH Clash.Annotations.TopEntity
    Clash.Class.AutoReg Clash.Class.AutoReg.Internal
    Clash.Class.BitPack Clash.Class.BitPack.BitIndex
    Clash.Class.BitPack.BitReduction Clash.Class.BitPack.Internal
    Clash.Class.BitPack.Internal.TH Clash.Class.Counter
    Clash.Class.Counter.Internal Clash.Class.Counter.TH Clash.Class.Exp
    Clash.Class.HasDomain Clash.Class.HasDomain.CodeGen
    Clash.Class.HasDomain.Common Clash.Class.HasDomain.HasSingleDomain
    Clash.Class.HasDomain.HasSpecificDomain Clash.Class.Num
    Clash.Class.Parity Clash.Class.Resize Clash.Clocks
    Clash.Clocks.Deriving Clash.Examples Clash.Examples.Internal
    Clash.Explicit.BlockRam Clash.Explicit.BlockRam.Blob
    Clash.Explicit.BlockRam.File Clash.Explicit.BlockRam.Internal
    Clash.Explicit.DDR Clash.Explicit.Mealy Clash.Explicit.Moore
    Clash.Explicit.Prelude Clash.Explicit.Prelude.Safe
    Clash.Explicit.RAM Clash.Explicit.ROM Clash.Explicit.ROM.Blob
    Clash.Explicit.ROM.File Clash.Explicit.Reset Clash.Explicit.Signal
    Clash.Explicit.Signal.Delayed Clash.Explicit.SimIO
    Clash.Explicit.Synchronizer Clash.Explicit.Testbench
    Clash.Explicit.Verification Clash.HaskellPrelude Clash.Hidden
    Clash.Intel.ClockGen Clash.Intel.DDR Clash.Magic Clash.NamedTypes
    Clash.Num.Erroring Clash.Num.Overflowing Clash.Num.Saturating
    Clash.Num.Wrapping Clash.Num.Zeroing Clash.Prelude
    Clash.Prelude.BitIndex Clash.Prelude.BitReduction
    Clash.Prelude.BlockRam Clash.Prelude.BlockRam.Blob
    Clash.Prelude.BlockRam.File Clash.Prelude.DataFlow
    Clash.Prelude.Mealy Clash.Prelude.Moore Clash.Prelude.RAM
    Clash.Prelude.ROM Clash.Prelude.ROM.Blob Clash.Prelude.ROM.File
    Clash.Prelude.Safe Clash.Prelude.Testbench Clash.Promoted.Nat
    Clash.Promoted.Nat.Literals Clash.Promoted.Nat.TH
    Clash.Promoted.Nat.Unsafe Clash.Promoted.Symbol Clash.Signal
    Clash.Signal.BiSignal Clash.Signal.Bundle Clash.Signal.Delayed
    Clash.Signal.Delayed.Bundle Clash.Signal.Delayed.Internal
    Clash.Signal.Internal Clash.Signal.Internal.Ambiguous
    Clash.Signal.Trace Clash.Sized.BitVector Clash.Sized.Fixed
    Clash.Sized.Index Clash.Sized.Internal.BitVector
    Clash.Sized.Internal.Index Clash.Sized.Internal.Mod
    Clash.Sized.Internal.Signed Clash.Sized.Internal.Unsigned
    Clash.Sized.RTree Clash.Sized.Signed Clash.Sized.Unsigned
    Clash.Sized.Vector Clash.Tutorial Clash.Verification
    Clash.Verification.DSL Clash.Verification.Internal Clash.XException
    Clash.XException.Internal Clash.XException.TH Clash.Xilinx.ClockGen
    Clash.Xilinx.DDR

hidden-modules:
    Clash.Class.AutoReg.Instances Clash.CPP
    Clash.Signal.Bundle.Internal Language.Haskell.TH.Compat
    Paths_clash_prelude

import-dirs:          /usr/lib/ghc-9.0.2/site-local/clash-prelude-1.6.6
library-dirs:         /usr/lib/ghc-9.0.2/site-local/clash-prelude-1.6.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-clash-prelude
hs-libraries:         HSclash-prelude-1.6.6-FjFoMXWmgppEiwr6KGaISr
depends:
    QuickCheck-2.14.3-AZ8mVeW5pFpW7DLfDGs2f array-0.5.4.0
    arrows-0.4.4.2-6X1p4BEtu6N98mFzUCK42Z base-4.15.1.0 binary-0.8.8.0
    bytestring-0.10.12.1 constraints-0.13.4-AM7hn70riinCUKOiE9i4xC
    containers-0.6.4.1 data-binary-ieee754-0.4.4-6nKeQnWkGoLJGejCHaRaWS
    data-default-class-0.1.2.0-IxhEAzgy8931aXcEiJcyZO deepseq-1.4.5.0
    extra-1.7.14-BeIxBD1TTw99mJxXRZbRjk ghc-bignum-1.1 ghc-prim-0.7.0
    ghc-typelits-extra-0.4.4-KOWoo7CvRnXG6KcNjVnpT6
    ghc-typelits-knownnat-0.7.8-H5oyuhMeXOvGCtsp2skequ
    ghc-typelits-natnormalise-0.7.7-vmp1340eiL6LMcwSulRM
    half-0.3.1-Zy1JFcoNMPHNzEnPesCLh
    hashable-1.4.3.0-4YBru6Kbt1R66z62BLV1oS
    interpolate-0.2.1-Gcwes4glEvvFI2kFiq395N
    lens-5.2.3-8AWELFAKeaF8YyQXTXJeRN
    recursion-schemes-5.2.2.5-6QcSw4v4hjo8tRGn7X7u8C
    reflection-2.1.7-LE9K8qz3HGV6oPdlpz2p7K
    singletons-3.0.2-93hmyY3AGblEf4xcAeOh3k template-haskell-2.17.0.0
    text-1.2.5.0 th-abstraction-0.4.5.0-CPrpKcr2W2S31K8QsJKgDp
    th-lift-0.8.4-4cyXLgXzVomInnuNEFv3vJ
    th-orphans-0.13.14-DNuW65fovPZJ1ob9IFOchL time-1.9.3
    transformers-0.5.6.2 type-errors-0.2.0.2-2QWNCpcedcSJ1DEi1HdJk2
    uniplate-1.6.13-985lFINZcyRLV6YoClFcF2
    vector-0.13.1.0-EglkR1WWsvHAgRWRD2OzaJ

haddock-interfaces:
    /usr/share/doc/haskell-clash-prelude/html/clash-prelude.haddock

haddock-html:         /usr/share/doc/haskell-clash-prelude/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-clash-prelude-1.8.1-80.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-clash-prelude.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 clash-prelude
version:              1.8.1
visibility:           public
id:                   clash-prelude-1.8.1-6ImNKCAXu8T9tvENeDPots
key:                  clash-prelude-1.8.1-6ImNKCAXu8T9tvENeDPots
license:              BSD-2-Clause
copyright:
    Copyright © 2013-2016, University of Twente,
    2016-2017, Myrtle Software Ltd,
    2017-2019, QBayLogic B.V., Google Inc.,
    2021-2023, QBayLogic B.V.

maintainer:           QBayLogic B.V. <devops@qbaylogic.com>
author:               The Clash Authors
homepage:             https://clash-lang.org/
synopsis:
    Clash: a functional hardware description language - Prelude library

description:
    Clash is a functional hardware description language that borrows both its
    syntax and semantics from the functional programming language Haskell. The
    Clash compiler transforms these high-level descriptions to low-level
    synthesizable VHDL, Verilog, or SystemVerilog.

    Features of Clash:

    * Strongly typed, but with a very high degree of type inference, enabling both
    safe and fast prototyping using concise descriptions.

    * Interactive REPL: load your designs in an interpreter and easily test all
    your component without needing to setup a test bench.

    * Higher-order functions, with type inference, result in designs that are
    fully parametric by default.

    * Synchronous sequential circuit design based on streams of values, called
    @Signal@s, lead to natural descriptions of feedback loops.

    * Support for multiple clock domains, with type safe clock domain crossing.


    This package provides:

    * Prelude library containing datatypes and functions for circuit design

    To use the library:

    * Import "Clash.Prelude"

    * Alternatively, if you want to explicitly route clock and reset ports,
    for more straightforward multi-clock designs, you can import the
    "Clash.Explicit.Prelude" module. Note that you should not import
    "Clash.Prelude" and "Clash.Explicit.Prelude" at the same time as they
    have overlapping definitions.

    A preliminary version of a tutorial can be found in "Clash.Tutorial", for a
    general overview of the library you should however check out "Clash.Prelude".
    Some circuit examples can be found in "Clash.Examples".

category:             Hardware
abi:                  8031d76dc5fdaf75ba776ea2825ce037
exposed:              True
exposed-modules:
    Clash.Annotations.BitRepresentation
    Clash.Annotations.BitRepresentation.Deriving
    Clash.Annotations.BitRepresentation.Internal
    Clash.Annotations.BitRepresentation.Util
    Clash.Annotations.Primitive Clash.Annotations.SynthesisAttributes
    Clash.Annotations.TH Clash.Annotations.TopEntity
    Clash.Class.AutoReg Clash.Class.AutoReg.Internal
    Clash.Class.BitPack Clash.Class.BitPack.BitIndex
    Clash.Class.BitPack.BitReduction Clash.Class.BitPack.Internal
    Clash.Class.BitPack.Internal.TH Clash.Class.Counter
    Clash.Class.Counter.Internal Clash.Class.Counter.TH Clash.Class.Exp
    Clash.Class.HasDomain Clash.Class.HasDomain.CodeGen
    Clash.Class.HasDomain.Common Clash.Class.HasDomain.HasSingleDomain
    Clash.Class.HasDomain.HasSpecificDomain Clash.Class.Num
    Clash.Class.Parity Clash.Class.Resize Clash.Clocks Clash.Examples
    Clash.Examples.Internal Clash.Explicit.BlockRam
    Clash.Explicit.BlockRam.Blob Clash.Explicit.BlockRam.File
    Clash.Explicit.BlockRam.Internal Clash.Explicit.BlockRam.Model
    Clash.Explicit.DDR Clash.Explicit.Mealy Clash.Explicit.Moore
    Clash.Explicit.Prelude Clash.Explicit.Prelude.Safe
    Clash.Explicit.RAM Clash.Explicit.ROM Clash.Explicit.ROM.Blob
    Clash.Explicit.ROM.File Clash.Explicit.Reset Clash.Explicit.Signal
    Clash.Explicit.Signal.Delayed Clash.Explicit.SimIO
    Clash.Explicit.Synchronizer Clash.Explicit.Testbench
    Clash.Explicit.Verification Clash.HaskellPrelude Clash.Hidden
    Clash.Intel.ClockGen Clash.Intel.DDR Clash.Magic Clash.NamedTypes
    Clash.Num.Erroring Clash.Num.Overflowing Clash.Num.Saturating
    Clash.Num.Wrapping Clash.Num.Zeroing Clash.Prelude
    Clash.Prelude.BlockRam Clash.Prelude.BlockRam.Blob
    Clash.Prelude.BlockRam.File Clash.Prelude.DataFlow
    Clash.Prelude.Mealy Clash.Prelude.Moore Clash.Prelude.RAM
    Clash.Prelude.ROM Clash.Prelude.ROM.Blob Clash.Prelude.ROM.File
    Clash.Prelude.Safe Clash.Prelude.Testbench Clash.Promoted.Nat
    Clash.Promoted.Nat.Literals Clash.Promoted.Nat.TH
    Clash.Promoted.Nat.Unsafe Clash.Promoted.Symbol Clash.Signal
    Clash.Signal.BiSignal Clash.Signal.Bundle Clash.Signal.Delayed
    Clash.Signal.Delayed.Bundle Clash.Signal.Delayed.Internal
    Clash.Signal.Internal Clash.Signal.Internal.Ambiguous
    Clash.Signal.Trace Clash.Sized.BitVector Clash.Sized.Fixed
    Clash.Sized.Index Clash.Sized.Internal.BitVector
    Clash.Sized.Internal.Index Clash.Sized.Internal.Mod
    Clash.Sized.Internal.Signed Clash.Sized.Internal.Unsigned
    Clash.Sized.RTree Clash.Sized.Signed Clash.Sized.Unsigned
    Clash.Sized.Vector Clash.Tutorial Clash.Verification
    Clash.Verification.DSL Clash.Verification.Internal Clash.XException
    Clash.XException.Internal Clash.XException.MaybeX
    Clash.XException.TH Clash.Xilinx.ClockGen Clash.Xilinx.DDR

hidden-modules:
    Clash.Class.AutoReg.Instances Clash.Clocks.Internal Clash.CPP
    Clash.Signal.Bundle.Internal Language.Haskell.TH.Compat
    Paths_clash_prelude

import-dirs:          /usr/lib/ghc-9.4.8/site-local/clash-prelude-1.8.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/clash-prelude-1.8.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/clash-prelude-1.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-clash-prelude
hs-libraries:         HSclash-prelude-1.8.1-6ImNKCAXu8T9tvENeDPots
depends:
    QuickCheck-2.14.3-Gpw9UoHUxB71c0Trj8n39O array-0.5.4.0
    arrows-0.4.4.2-FA2ByHWzVXpCrKEu55F0dw base-4.17.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 constraints-0.13.4-GRCASd6TdIJDk065yZIoKs
    containers-0.6.7 data-binary-ieee754-0.4.4-3K4wyZ8KRa1CgKftL8GYsk
    data-default-class-0.1.2.0-J3yYo85AtrC9KKZSpt62Yc deepseq-1.4.8.0
    extra-1.7.16-CikHmmEQvn83rCDobzYCEG ghc-bignum-1.3 ghc-prim-0.9.1
    ghc-typelits-extra-0.4.5-KlpMrgnLQoJ5HOn5i0xpiO
    ghc-typelits-knownnat-0.7.8-LTXheM2BWYMKLr3YyZJVHR
    ghc-typelits-natnormalise-0.7.9-2wH8ndsY9Gy7jWyzJeJ3Sl
    half-0.3.2-E7GsfcAdAl1FGkf6dksMcx
    hashable-1.4.4.0-AT2Ub72SgpTFIbLYNtgVpj
    infinite-list-0.1.2-1yEzfRuWUDPALPpM0JIQf1
    lens-5.2.3-7k2QwsHyLcVK6NgbwpIzej mtl-2.2.2
    recursion-schemes-5.2.3-ATdKjpDYLBF5pEk2dMF55p
    reflection-2.1.9-CfmPTLnbYKpGH4CnnGKIjC
    singletons-3.0.4-5pDsUnwe3c7FZQt4Yt8MEN
    string-interpolate-0.3.4.0-3pPvg9FpEjl2JaQftnXpLc
    template-haskell-2.19.0.0 text-2.0.2
    th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy
    th-lift-0.8.5-3bCWMcLwp8dEXoRnv4Yrhx
    th-orphans-0.13.15-EtOS7liwMoCCsuNi9Alz55 time-1.12.2
    transformers-0.5.6.2 type-errors-0.2.0.2-AKfcmhN25IH3PnW43OGrWT
    uniplate-1.6.13-FPxTMXtfUHnEXogiyqcBmu
    vector-0.13.2.0-H3MTIE0bxkOEYwCD854O16

haddock-interfaces:
    /usr/share/doc/haskell-clash-prelude/html/clash-prelude.haddock

haddock-html:         /usr/share/doc/haskell-clash-prelude/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
